@@ -21,7 +21,7 @@
 #include "playerselectoritem.h"
 #include "playersettings.h"
 
-#include <QtCore/QPointer>
+#include <QPointer>
 #include <QAbstractItemView>
 #include <QApplication>
 #include <QCloseEvent>
@@ -34,7 +34,7 @@
 #include <QScrollBar>
 #include <QVBoxLayout>
 #include <QSpacerItem>
-#include <QtSvg/QSvgRenderer>
+#include <QSvgRenderer>
 #include <QStandardPaths>
 #include <KConfig>
 #include <KLocalizedString>
@@ -90,7 +90,7 @@ PlayerSelector::PlayerSelector(PlayerSettings* playerSettings, Options options,
     //setup KNS button
     if (options & EnableNewStuffDownload)
     {
-        d->m_knsButton = new QPushButton(QIcon::fromTheme("get-hot-new-stuff"),
+        d->m_knsButton = new QPushButton(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")),
             i18n("Get New Players..."), this);
         layout->addWidget(d->m_knsButton);
         connect(d->m_knsButton, SIGNAL(clicked()), SLOT(_k_showNewStuffDialog()));
@@ -125,12 +125,12 @@ void PlayerSelector::Private::fillList()
         playerSelectorItem = new PlayerSelectorItem(playerIDs[i], m_playerSettings, m_list);
 
         renderer.load(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("players/%1").arg(m_playerSettings->playerGraphicsFile(playerIDs[i]))));
-        renderer.render(&pixPainter, "player_0");
+        renderer.render(&pixPainter, QStringLiteral("player_0"));
         playerSelectorItem->setPlayerPreviewPixmap(pixmap);
         
         KConfig desktopFile(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("players/%1").arg(playerIDs[i])), KConfig::SimpleConfig);
-        QString author = desktopFile.group("KGameTheme").readEntry<QString>("Author", "");
-        QString authorEmail = QString("<a href=\"mailto:%1\">%1</a>").arg(desktopFile.group("KGameTheme").readEntry<QString>("AuthorEmail", ""));
+        QString author = desktopFile.group("KGameTheme").readEntry<QString>("Author", QStringLiteral(""));
+        QString authorEmail = QStringLiteral("<a href=\"mailto:%1\">%1</a>").arg(desktopFile.group("KGameTheme").readEntry<QString>("AuthorEmail", QStringLiteral("")));
         //TODO: QString description = desktopFile.group("KGameTheme").readEntry<QString>("Description", "");
         playerSelectorItem->setPlayerAuthor(author, authorEmail);
         
